@@ -18,6 +18,7 @@
 #' @import openalexR
 #' @import ca
 #' @importFrom dplyr %>%
+#' @importFrom dplyr bind_cols
 #' @importFrom dplyr across
 #' @importFrom dplyr row_number
 #' @importFrom dplyr tibble
@@ -736,3 +737,10 @@ colorlist <- function(){
              ,"#B3B3B3","#A6CEE3","#1F78B4","#B2DF8A","#33A02C","#FB9A99","#E31A1C","#FDBF6F","#FF7F00","#CAB2D6","#6A3D9A","#B15928","#8DD3C7","#BEBADA"
              ,"#FB8072","#80B1D3","#FDB462","#B3DE69","#D9D9D9","#BC80BD","#CCEBC5")
 }
+
+#Initial to upper case
+firstup <- function(x) {
+  x <- tolower(x)
+  substr(x, 1, 1) <- toupper(substr(x, 1, 1))
+  x
+}
\ No newline at end of file
